# Api_Implementations 

[![Coverage Status](https://coveralls.io/repos/github/Rish71/api_implementations/badge.svg)](https://coveralls.io/github/Rish71/api_implementations) [![Documentation Status](https://readthedocs.org/projects/api-implementations/badge/?version=latest)](https://api-implementations.readthedocs.io/en/latest/?badge=latest)

Api_implementations contains a set of basic server client interacting modules. 

They are designed in a way to integrate and change them as per need within other projects.
